# -*- coding: utf-8 -*-

from django.shortcuts import get_object_or_404
from django.utils.translation import ugettext as _
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from filer.models import Folder, File as FolderFile

from jmb.document.cms.models import DocumentSettings


class DocumentPlugin(CMSPluginBase):
    model = DocumentSettings
    name = _("Document Plugin")
    module = _("Document")
    admin_preview = False

    def render(self, context, instance, placeholder):
        self.render_template = instance.template_name
        root_folder = get_object_or_404(Folder, name=instance.dirpath)
        folders = [{
            'folder': folder,
            'files': [f for f in FolderFile.objects.filter(folder=folder).order_by('name')]
        } for folder in root_folder.get_descendants().order_by('name')]
        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'folders': folders,
        })
        return context


plugin_pool.register_plugin(DocumentPlugin)

